@@ -17,7 +17,7 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
-#include "importertest.moc"
+#include "importertest.h"
 
 // stdlib
 #include <sys/stat.h>
@@ -26,9 +26,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <QSignalSpy>
 
 // KDE
-#include <KDateTime>
-#include <KDebug>
-#include <qtest_kde.h>
+#include <QDateTime>
+#include <QDebug>
+#include <qtest.h>
 
 // Local
 #include "../importer/fileutils.h"
@@ -36,7 +36,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "../importer/filenameformater.h"
 #include "testutils.h"
 
-QTEST_KDEMAIN(ImporterTest, GUI)
+QTEST_MAIN(ImporterTest)
 
 using namespace Gwenview;
 
@@ -81,7 +81,7 @@ void ImporterTest::testContentsAreIdentical()
 
 void ImporterTest::testSuccessfulImport()
 {
-    KUrl destUrl = KUrl::fromPath(mTempDir->name() + "/foo");
+    KUrl destUrl = QUrl::fromLocalFile(mTempDir->name() + "/foo");
 
     Importer importer(0);
     QSignalSpy maximumChangedSpy(&importer, SIGNAL(maximumChanged(int)));
@@ -112,7 +112,7 @@ void ImporterTest::testSuccessfulImport()
 
 void ImporterTest::testSkippedUrlList()
 {
-    KUrl destUrl = KUrl::fromPath(mTempDir->name() + "/foo");
+    KUrl destUrl = QUrl::fromLocalFile(mTempDir->name() + "/foo");
 
     Importer importer(0);
 
@@ -140,7 +140,7 @@ void ImporterTest::testSkippedUrlList()
 
 void ImporterTest::testRenamedCount()
 {
-    KUrl destUrl = KUrl::fromPath(mTempDir->name() + "/foo");
+    KUrl destUrl = QUrl::fromLocalFile(mTempDir->name() + "/foo");
 
     Importer importer(0);
 
@@ -183,7 +183,7 @@ void ImporterTest::testFileNameFormater()
 
     KUrl url = KUrl("file://foo/bar/" + fileName);
     FileNameFormater fileNameFormater(format);
-    QCOMPARE(fileNameFormater.format(url, KDateTime::fromString(dateTime)), expected);
+    QCOMPARE(fileNameFormater.format(url, QDateTime::fromString(dateTime)), expected);
 }
 
 #define NEW_ROW(fileName, dateTime, format, expected) QTest::newRow(fileName) << fileName << dateTime << format << expected
@@ -212,7 +212,7 @@ void ImporterTest::testAutoRenameFormat()
                         << "2009-10-01_21-15-27";
     QCOMPARE(dates.count(), mDocumentList.count());
 
-    KUrl destUrl = KUrl::fromPath(mTempDir->name() + "foo");
+    KUrl destUrl = QUrl::fromLocalFile(mTempDir->name() + "foo");
 
     Importer importer(0);
     importer.setAutoRenameFormat("{date}_{time}.{ext}");
@@ -236,7 +236,7 @@ void ImporterTest::testAutoRenameFormat()
 
 void ImporterTest::testReadOnlyDestination()
 {
-    KUrl destUrl = KUrl::fromPath(mTempDir->name() + "/foo");
+    KUrl destUrl = QUrl::fromLocalFile(mTempDir->name() + "/foo");
     chmod(QFile::encodeName(mTempDir->name()), 0555);
 
     Importer importer(0);
